@@ -48,7 +48,7 @@ from ctypes import c_char_p, c_int, c_void_p, create_string_buffer, \
                     POINTER, byref, CDLL, cdll, util, cast
 c_int_p = POINTER(c_int)
 
-__version__ = '5.5.4'
+__version__ = '5.5.5'
 
 __all__ = ['get_version', 'lut_load', 'lut_is_valid', 'cleanup',
             'check_iban', 'create_iban', 'get_bic', 'get_name',
@@ -94,10 +94,11 @@ def scl_get_routing(bic):
     BIC from the SCL directory, published by the German Central Bank.
     """
     bic = bic.upper()
-    if len(bic) == 8:
-        bic = bic.ljust(11, 'X')
+    if len(bic) not in (8, 11):
+        raise ValueError('invalid bic "%s"' % bic)
+    bic = bic.ljust(11, 'X')
     cur = dbscl.cursor()
-    cur.execute("SELECT sct, sdd, cor1, b2b FROM scl WHERE bic = ?;", (bic,))
+    cur.execute("SELECT sct, sdd, cor1, b2b FROM scl WHERE bic = ? OR bic = ?;", (bic, bic[:8]))
     result = cur.fetchone()
     cur.close()
     if not result:
@@ -110,15 +111,16 @@ def scl_get_bankname(bic):
     published by the German Central Bank.
     """
     bic = bic.upper()
-    if len(bic) == 8:
-        bic = bic.ljust(11, 'X')
+    if len(bic) not in (8, 11):
+        raise ValueError('invalid bic "%s"' % bic)
+    bic = bic.ljust(11, 'X')
     cur = dbscl.cursor()
-    cur.execute("SELECT name FROM scl WHERE bic = ?;", (bic,))
+    cur.execute("SELECT name FROM scl WHERE bic = ? OR bic = ?;", (bic, bic[:8]))
     result = cur.fetchone()
     cur.close()
     if not result:
         raise ValueError('unknown bic "%s"' % bic)
-    return result['name']
+    return result['name'].encode('utf-8')
 
 def bff_check_vatid(local_vatid, remote_vatid, company='', city='',
                         postalcode='', street='', request_mail=False):
